@@ -574,7 +574,9 @@ def ListChangedSince(rp):
 	restore_check_backup_dir(mirror_root)
 	mirror_rp = mirror_root.new_index(index)
 	inc_rp = mirror_rp.append_path("increments", index)
-	restore.ListChangedSince(mirror_rp, inc_rp, rest_time)
+	for rorp in rp.conn.restore.ListChangedSince(mirror_rp, inc_rp, rest_time):
+		# This is a hack, see restore.ListChangedSince for rational
+		print rorp.index[0]
 
 
 def ListAtTime(rp):
@@ -585,7 +587,8 @@ def ListAtTime(rp):
 	restore_check_backup_dir(mirror_root)
 	mirror_rp = mirror_root.new_index(index)
 	inc_rp = mirror_rp.append_path("increments", index)
-	restore.ListAtTime(mirror_rp, inc_rp, rest_time)
+	for rorp in rp.conn.restore.ListAtTime(mirror_rp, inc_rp, rest_time):
+		print rorp.get_indexpath()
 	
 
 def CheckDest(dest_rp):
