@@ -154,7 +154,7 @@ def copy_attribs(rpin, rpout):
 	check_for_files(rpin, rpout)
 	if rpin.issym(): return # symlinks have no valid attributes
 	if Globals.change_ownership: apply(rpout.chown, rpin.getuidgid())
-	if Globals.change_permissions: rpout.chmod(rpin.getperms())
+	rpout.chmod(rpin.getperms())
 	if not rpin.isdev(): rpout.setmtime(rpin.getmtime())
 
 def cmp_attribs(rp1, rp2):
@@ -216,7 +216,7 @@ def make_socket_local(rpath):
 
 	"""
 	assert rpath.conn is Globals.local_connection
-	s = socket.socket(socket.AF_UNIX)
+	s = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
 	try: s.bind(rpath.path)
 	except socket.error, exc:
 		raise SkipFileException("Socket error: " + str(exc))
@@ -261,7 +261,6 @@ class RORPath:
 		for key in self.data.keys(): # compare dicts key by key
 			if (key == 'uid' or key == 'gid') and self.issym():
 				pass # Don't compare gid/uid for symlinks
-			elif key == 'perms' and not Globals.change_permissions: pass
 			elif key == 'atime' and not Globals.preserve_atime: pass
 			elif key == 'devloc' or key == 'nlink': pass
 			elif key == 'size' and not self.isreg(): pass
@@ -294,7 +293,6 @@ class RORPath:
 			elif key == 'atime' and not Globals.preserve_atime: pass
 			elif key == 'devloc' or key == 'nlink': pass
 			elif key == 'size' and not self.isreg(): pass
-			elif key == 'perms' and not Globals.change_permissions: pass
 			elif key == 'inode': pass
 			elif (not other.data.has_key(key) or
 				  self.data[key] != other.data[key]): return 0
@@ -312,7 +310,6 @@ class RORPath:
 				(self.issym() or not compare_ownership)):
 				# Don't compare gid/uid for symlinks, or if told not to
 				pass
-			elif key == 'perms' and not Globals.change_permissions: pass
 			elif key == 'atime' and not Globals.preserve_atime: pass
 			elif key == 'devloc' or key == 'nlink': pass
 			elif key == 'size' and not self.isreg(): pass
@@ -828,6 +825,14 @@ class RPath(RORPath):
 			raise RPathException("Error closing file")
 		self.setdata()
 
+	def write_string(self, s, compress = None):
+		"""Write string s into rpath"""
+		assert not self.lstat(), "File %s already exists" % (self.path,)
+		outfp = self.open("wb", compress = compress)
+		outfp.write(s)
+		assert not outfp.close()
+		self.setdata()
+
 	def isincfile(self):
 		"""Return true if path looks like an increment file
 
